@@ -139,12 +139,12 @@ class NativeMethods(object):
                 print("Quarantine attribute removed successfully.")
             except subprocess.CalledProcessError as e:
                 print(f"Failed to remove quarantine attribute")
+    
     def _load_macos_libraries(self):
 
         self._library_path = str(self._local_lib_path.joinpath("libprivid_fhe_universal.dylib").resolve())
         self._spl_so_face = ctypes.CDLL(self._library_path)
 
-
     def _initialize_properties(self, api_key, server_url,logging_level):
         self._api_key = bytes(api_key, "utf-8")
         self._server_url = bytes(server_url, "utf-8")
@@ -596,7 +596,6 @@ class NativeMethods(object):
             print(e)
             return False
 
-
     def get_iso_face(
         self, image_data: np.array, config_object: ConfigObject = None
     ) -> Any:
@@ -742,15 +741,14 @@ class NativeMethods(object):
             )
             p_buffer_result = c_char_p()
             p_buffer_result_length = c_int()
-            config_object_default = {"face_thresholds_rem_bad_emb_default": 1.24, "face_thresholds_med": 1.24,"conf_score_thr_enroll":0.2}
+            config_object_default = {"face_thresholds_med": 1.00}
             if config_object and hasattr(config_object, 'get_config_param') and config_object.get_config_param():
                 config_param_str = config_object.get_config_param()
                 config_from_object = json.loads(config_param_str)
                 for key, value in config_object_default.items():
                     if key not in config_from_object:
-                        config_from_object[key] = value
-                config_from_object["face_thresholds_rem_bad_emb_default"]=config_from_object["face_thresholds_med"]
-                config_param_str = json.dumps(config_from_object)
+                        config_from_object[key] = value                
+                config_param_str = json.dumps(config_from_object)                
             else:
                 config_param_str = json.dumps(config_object_default)
              
@@ -1019,22 +1017,32 @@ class NativeMethods(object):
 
                 c_result = c_char_p()
                 c_result_len = c_int()
-                with_model_stdd = False
+                with_model_stdd = False 
+                if config_object and hasattr(config_object, '_get_param_value'):                    
+                    value = config_object._get_param_value(PARAMETERS.USE_AGE_ESTIMATION_WITH_MODEL_STDD) 
+                    if value is not None and isinstance(value, bool):
+                        with_model_stdd = value
+
                 config_json = None
 
                 if config_object and config_object.get_config_param():
-                   with_model_stdd =  config_object._get_param_value(PARAMETERS.USE_AGE_ESTIMATION_WITH_MODEL_STDD)     
                    config_json = config_object.get_config_param()                
                 
                 if config_object and config_json:
                     # Load existing config from the object
                     config_dict = json.loads(config_json)
-                    # Ensure disable_enroll_mf is always added
-                    config_dict["skip_antispoof"] = True
+                    # Disable antispoof by default if not set
+                    if "skip_antispoof" not in config_dict:
+                        config_dict["skip_antispoof"] = True
                     config_dict["conf_score_thr_enroll"]=0.2                    
                 else:
                     # Create a new config dict with disable_enroll_mf set to True
-                    config_dict = {"skip_antispoof": True,"conf_score_thr_enroll":0.2}                    
+                    config_dict = {"skip_antispoof": True,"conf_score_thr_enroll":0.2}         
+
+                # If skip_antispoof is True, force single_face_age_result to True
+                # as our antispoof is not supported for multiple faces detection                
+                if config_dict["skip_antispoof"] == False:
+                    config_dict["single_face_age_result"] = True
                 
                 config_json = json.dumps(config_dict)
                 c_config_param = c_char_p(bytes(config_json, "utf-8"))
